==> crypt-data-5.2-sources.jar: de/alpharogroup/crypto/obfuscation/rules/ObfuscationBiMapRules.java <==
/**
 * The MIT License
 *
 * Copyright (C) 2015 Asterios Raptis
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 * OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
package de.alpharogroup.crypto.obfuscation.rules;

import com.google.common.collect.BiMap;

import de.alpharogroup.check.Check;
import lombok.AccessLevel;
import lombok.Builder;
import lombok.EqualsAndHashCode;
import lombok.Getter;
import lombok.Setter;
import lombok.ToString;
import lombok.experimental.FieldDefaults;

/**
 * The class {@link ObfuscationBiMapRules} decorates a {@link BiMap} that defines rules for encrypt
 * and decrypt given strings.
 */
@Getter
@Setter
@EqualsAndHashCode
@ToString
@FieldDefaults(level = AccessLevel.PRIVATE)
@Builder
public class ObfuscationBiMapRules<K, V>
{

	/**
	 * The rules for encrypt the string.
	 */
	private final BiMap<K, V> obfuscationRules;

	/**
	 * Instantiates a new {@link ObfuscationBiMapRules}.
	 *
	 * @param obfuscationRules
	 *            the obfuscation rules for obfuscate and disentangle.
	 */
	public ObfuscationBiMapRules(final BiMap<K, V> obfuscationRules)
	{
		Check.get().notEmpty(obfuscationRules, "obfuscationRules");
		this.obfuscationRules = obfuscationRules;
	}

}

==> crypt-data-7.2-sources.jar: de/alpharogroup/crypto/obfuscation/rules/ObfuscationBiMapRules.java <==
/**
 * The MIT License
 *
 * Copyright (C) 2015 Asterios Raptis
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 * OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
package de.alpharogroup.crypto.obfuscation.rules;

import com.google.common.collect.BiMap;

import lombok.AccessLevel;
import lombok.Builder;
import lombok.EqualsAndHashCode;
import lombok.Getter;
import lombok.NonNull;
import lombok.Setter;
import lombok.ToString;
import lombok.experimental.FieldDefaults;

/**
 * The class {@link ObfuscationBiMapRules} decorates a {@link BiMap} that defines rules for encrypt
 * and decrypt given strings.
 */
@Getter
@Setter
@EqualsAndHashCode
@ToString
@FieldDefaults(level = AccessLevel.PRIVATE)
@Builder
public class ObfuscationBiMapRules<K, V>
{

	/**
	 * The rules for encrypt the string.
	 */
	private final BiMap<K, V> obfuscationRules;

	/**
	 * Instantiates a new {@link ObfuscationBiMapRules}.
	 *
	 * @param obfuscationRules
	 *            the obfuscation rules for obfuscate and disentangle.
	 */
	public ObfuscationBiMapRules(@NonNull final BiMap<K, V> obfuscationRules)
	{
		this.obfuscationRules = obfuscationRules;
	}

}
